import { Component, OnInit } from '@angular/core';
import { HttpClient } from '@angular/common/http';
interface ClientInfo {
  property: string;
  value: any;
}

@Component({
  selector: 'app-client-main-view',
  templateUrl: './client-main-view.component.html',
  styleUrl: './client-main-view.component.css'
})
export class ClientMainViewComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  clientUuid: string;
  clientData: any = {};
  isPartitionAssistantVisible: boolean = false;
  isBootImageVisible: boolean = false;
  isGeneralInfoVisible: boolean = true;
  isDiskUsageVisible: boolean = true;

  displayedColumns: string[] = ['property', 'value'];

  generalData: ClientInfo[] = [];
  networkData: ClientInfo[] = [];
  classroomData: ClientInfo[] = [];

  constructor(private http: HttpClient) {
    const url = window.location.href;
    const segments = url.split('/');
    this.clientUuid = segments[segments.length - 1];
  }

  ngOnInit() {
    this.clientData = history.state.clientData
    this.updateGeneralData();
    this.updateNetworkData();
    this.updateClassroomData();
  }

  updateGeneralData() {
    this.generalData = [
      { property: 'Nombre', value: this.clientData?.name || '' },
      { property: 'Uuid', value: this.clientData?.uuid || '' },
      { property: 'IP', value: this.clientData?.ip || '' },
      { property: 'MAC', value: this.clientData?.mac || '' },
      { property: 'Nº de serie', value: this.clientData?.serialNumber || '' },
      { property: 'Netiface', value: this.clientData?.netiface || '' },
      { property: 'Perfil hardware', value: this.clientData?.hardwareProfile?.description || '' },
      { property: 'Menú', value: this.clientData?.menu?.description || '' },
      { property: 'Fecha de creación', value: this.clientData?.createdAt || '' },
      { property: 'Creado por', value: this.clientData?.createdBy || '' }
    ];
  }
  updateNetworkData() {
    this.networkData = [
      { property: 'Perfil hardware', value: this.clientData?.hardwareProfile?.description || '' },
      { property: 'Subred', value: this.clientData?.subnet || '' },
      { property: 'OGlive', value: '' },
      { property: 'Autoexec', value: '' },
      { property: 'Repositorio', value: '' },
      { property: 'Validación', value: this.clientData?.organizationalUnit?.networkSettings?.validation || '' },
      { property: 'Fecha de creación', value: this.clientData?.createdAt || '' },
      { property: 'Creado por', value: this.clientData?.createdBy || '' }
    ];
  }

  updateClassroomData() {
    this.classroomData = [
      { property: 'Url servidor proxy', value: this.clientData?.organizationalUnit?.networkSettings?.proxy || '' },
      { property: 'IP DNS', value: this.clientData?.organizationalUnit?.networkSettings?.dns || '' },
      { property: 'Máscara de red', value: this.clientData?.organizationalUnit?.networkSettings?.netmask || '' },
      { property: 'Router', value: this.clientData?.organizationalUnit?.networkSettings?.router || '' },
      { property: 'NTP', value: this.clientData?.organizationalUnit?.networkSettings?.ntp || '' },
      { property: 'Modo p2p', value: this.clientData?.organizationalUnit?.networkSettings?.p2pMode || '' },
      { property: 'Tiempo p2p', value: this.clientData?.organizationalUnit?.networkSettings?.p2pTime || '' },
      { property: 'IP multicast', value: this.clientData?.organizationalUnit?.networkSettings?.mcastIp || '' },
      { property: 'Modo multicast', value: this.clientData?.organizationalUnit?.networkSettings?.mcastMode || '' },
      { property: 'Puerto multicast', value: this.clientData?.organizationalUnit?.networkSettings?.mcastPort || '' },
      { property: 'Velocidad multicast', value: this.clientData?.organizationalUnit?.networkSettings?.mcastSpeed || '' },
      { property: 'Perfil hardware', value: this.clientData?.organizationalUnit?.networkSettings?.hardwareProfile?.description || '' }
    ];
  }

  togglePartitionAssistant() {
    this.isPartitionAssistantVisible = !this.isPartitionAssistantVisible;
    this.isBootImageVisible = false;
  }

  showBootImage() {
    this.isPartitionAssistantVisible = false;
    this.isBootImageVisible = !this.isBootImageVisible;
  }
}
